developerscripttools.PyTestScript
=================================

.. abjad-lineage:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript

.. autoclass:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.PyTestScript.PyTestScript.PyTestScript.__repr__
   :noindex:
